# ==============
# File: server.py
# By: Jack Holdsworth - 20023933
# Use: Task 3, a program to communicate with the server
# Written on: Python 3.8
# ==============

import asyncio
import websockets
import json
import time


async def main(str):
    uri = "ws://localhost:10102"
    async with websockets.connect(uri) as websocket:
        # After joining server will send client unique id.
        message = json.loads(await websocket.recv())
        print(message)
        # Get the client_id from the join message
        if message['type'] == 'join_evt':
            client_id = message['client_id']
            # Send a ping to the server
            await send_message(websocket, str, client_id)
            # Wait for the 'ping' response from the server
            response = await recv_message(websocket)
            print("The Server Sent Back:")
            print(response)

        else:
            # If first message is not the join message exit
            print("Did not receive a correct join message")
            return 0
        return response

async def send_message(websocket, message, client_id):
    outward_message = {
    'type' : 'morse_evt',
    'client_id': client_id,
    'payload': message
    }
    await websocket.send(json.dumps(outward_message))

async def recv_message(websocket):
    message = json.loads(await websocket.recv())
    return message['payload']


if __name__ == "__main__":
    print("Echo client")

    while 1:
        time.sleep(1)
        asyncio.run(main('. -.-. .... --- -.. . .--- .- -.-. -.- -...- .. --- -   .. ...   - .... .   -... . ... -   -- --- -.. ..- .-.. . -...- -.--.'))
