# ==============
# File: unittest.py
# By: Jack Holdsworth - 20023933
# Use: A simple unittest file for worksheet2 part 2
# Written on: Python 3.8
# ==============

import unittest
import binaryheap
import hamradio
import hamserver
import datetime 
class TestMorse(unittest.TestCase):
# task 1
    # decode_bt tests
    def test_decode_bt_us(self):
        self.assertEqual( binaryheap.decode_bt('..- ...'), 'US')
    def test_decode_bt_hello_again(self):
        self.assertEqual( binaryheap.decode_bt('.... . .-.. .-.. ---  .- --. .- .. -.'), 'HELLO AGAIN')
    def test_decode_bt_IOt_IS_ThE_bESt(self):
        self.assertEqual( binaryheap.decode_bt('.. --- -  .. ...  - .... .  -... . ... -'), 'IOT IS THE BEST')
    def test_decode_bt_CAPITALS(self):
        self.assertEqual( binaryheap.decode_bt('-.-. .- .--. .. - .- .-.. ...'), 'CAPITALS')
    def test_decode_bt_incorrect(self):
        self.assertEqual( binaryheap.decode_bt('.. -. -.-. --- .-. .-. . -.-. -'), 'CORRECT')
    def test_decode_bt_numbers(self):
        self.assertEqual( binaryheap.decode_bt('.. -  -.. --- . ... -. -  -.. ---  -. ..- -- -... . .-. ...'), '123')
    def test_decode_bt_special_chars(self):
        self.assertEqual( binaryheap.decode_bt('.. -  -.. --- . ... -. -  -.. ---  ... .--. . -.-. .. .- .-..  -.-. .... .- .-. ...'), '@&%')
    
    #  addition tests.
    def test_decode_bt_question_mark(self):
        self.assertEqual( binaryheap.decode_bt('..--.'), '?')
    def test_decode_bt_dollar(self):
        self.assertEqual( binaryheap.decode_bt('...-..-'), '$')
    def test_decode_bt_colon(self):
        self.assertEqual( binaryheap.decode_bt('---...'), ':')
# task 2
    # encode
    def test_encode_ham_1(self):
        self.assertEqual( hamradio.encode_ham('s','r','message'), '.-. -.. . ... -...- -- . ... ... .- --. . -...- -.--.')
    def test_encode_ham_2(self):
        self.assertEqual( hamradio.encode_ham('JACK','IOT','YOU ARE THE BEST MODULE'), '.. --- - -.. . .--- .- -.-. -.- -...- -.-- --- ..-  .- .-. .  - .... .  -... . ... -  -- --- -.. ..- .-.. . -...- -.--.')
    def test_encode_ham_3(self):
        self.assertEqual( hamradio.encode_ham('IOT','JACK','you are the best student'), '.--- .- -.-. -.- -.. . .. --- - -...- -.-- --- ..-  .- .-. .  - .... .  -... . ... -  ... - ..- -.. . -. - -...- -.--.')
    def test_encode_ham_4(self):
        self.assertEqual( hamradio.encode_ham('syntaxViolation','de','does It work'), '-.. . -.. . ... -.-- -. - .- -..- ...- .. --- .-.. .- - .. --- -. -...- -.. --- . ...  .. -  .-- --- .-. -.- -...- -.--.')
    def test_encode_ham_5(self):
        self.assertEqual( hamradio.encode_ham('incorrect','correct','it shouldn\'t work'), '-.-. --- .-. .-. . -.-. - -.. . .. -. -.-. --- .-. .-. . -.-. - -...- .. -  ... .... --- ..- .-.. -.. -. .----. -  .-- --- .-. -.- -...- -.--.')
    # decode
    def test_decode_ham_1(self):
        self.assertEqual( hamradio.decode_ham('.-. -.. . ... -...- -- . ... ... .- --. . -...- -.--.'), ('R','S','MESSAGE'))
    def test_decode_ham_2(self):
        self.assertEqual( hamradio.decode_ham('.. --- - -.. . .--- .- -.-. -.- -...- -.-- --- ..-  .- .-. .  - .... .  -... . ... -  -- --- -.. ..- .-.. . -...- -.--.'), ('IOT','JACK','YOU ARE THE BEST MODULE'))
    def test_decode_ham_3(self):
        self.assertEqual( hamradio.decode_ham('.--- .- -.-. -.- -.. . .. --- - -...- -.-- --- ..-  .- .-. .  - .... .  -... . ... -  ... - ..- -.. . -. - -...- -.--.'), ('JACK','IOT','YOU ARE THE BEST STUDENT'))
    def test_decode_ham_4(self):
        self.assertEqual( hamradio.decode_ham('-.. . -.. . ... -.-- -. - .- -..- ...- .. --- .-.. .- - .. --- -. -...- -.. --- . ...  .. -  .-- --- .-. -.- -...- -.--.'), ('DE','SYNTAXVIOLATION','DOES IT WORK'))
    def test_decode_ham_5(self):
        self.assertEqual( hamradio.decode_ham('-.-. --- .-. .-. . -.-. - -.. . .. -. -.-. --- .-. .-. . -.-. - -...- .. -  ... .... --- ..- .-.. -.. -. .----. -  .-- --- .-. -.- -...- -.--.'), ('CORRECT','INCORRECT','IT SHOULDN\'T WORK'))
 
# task 3
    # echo
    def test_echo_ham_1(self):
        self.assertEqual( hamserver.send_echo('s','message'), ('S', 'ECHO', 'MESSAGE'))
    def test_echo_ham_2(self):
        self.assertEqual( hamserver.send_echo('Jack','IOT IS THE BEST MODULE'), ('JACK', 'ECHO', 'IOT IS THE BEST MODULE'))
    def test_echo_ham_3(self):
        self.assertEqual( hamserver.send_echo('IOT','YOU ARE THE BEST STUDENT'), ('IOT', 'ECHO', 'YOU ARE THE BEST STUDENT'))
    def test_echo_ham_4(self):
        self.assertEqual( hamserver.send_echo('student','error'), ('STUDENT', 'ECHO', 'ERRORS'))
    def test_echo_ham_5(self):
        self.assertEqual( hamserver.send_echo('hi','its me'), ('ITS ME', 'ECHO', 'HI'))
    # time
    def test_echo_ham_1(self):
        self.assertEqual( hamserver.send_time('Jack'), ('JACK', 'TIME', datetime.datetime.now().strftime("%H:%M:%S")))
    def test_echo_ham_2(self):
        self.assertEqual( hamserver.send_time('IOT'), ('IOT', 'TIME', datetime.datetime.now().strftime("%H:%M:%S")))
if __name__ == '__main__':
    unittest.main()
